pub enum AlgorithmenError {
NotEnoughSpace,
NoElementLeft,
ItemToBigForBin,
}Expand description
Errors for AlgorithmenFirst
Variants
NotEnoughSpace
Bin has for the packages not enough space left {0}
NoElementLeft
No Element was found in the list, should not be possible
ItemToBigForBin
Item was to big for item